# Frequently Asked Questions

- [How do I add an ODE output to the timeseries outputs?](add_ode_output_to_timeseries.md)
- [How do I connect a scalar input to the ODE?](connect_scalar_parameters_to_ode.md)
- [How do connect the outputs of an upstream analysis as inputs to Dymos?](upstream_analysis.md)
- [How do connect the outputs of Dymos to a downstream analysis?](downstream_analysis.md)
- [How do I run two phases parallel-in-time?](tandem_phases.md)
- [How can I more efficiently use finite-differenced components in the ODE?](use_partial_coloring.md)
- [How can I debug models when things go wrong?](debugging.md)